import { JsPsychPlugin, ParameterType, JsPsych, TrialType } from 'jspsych';

declare const info: {
    readonly name: "spatial-nback";
    readonly version: string;
    readonly parameters: {
        /** Number of rows in the spatial grid */
        readonly rows: {
            readonly type: ParameterType.INT;
            readonly default: 3;
        };
        /** Number of columns in the spatial grid */
        readonly cols: {
            readonly type: ParameterType.INT;
            readonly default: 3;
        };
        /** Size of each cell in pixels, this will affect size of whole grid also. If null, defaults to 12vh (12% of viewport height) */
        readonly cell_size: {
            readonly type: ParameterType.INT;
            readonly default: any;
        };
        /** Row position of the stimulus (0-indexed). If null, no stimulus is shown. */
        readonly stimulus_row: {
            readonly type: ParameterType.INT;
            readonly default: any;
        };
        /** Column position of the stimulus (0-indexed). If null, no stimulus is shown. */
        readonly stimulus_col: {
            readonly type: ParameterType.INT;
            readonly default: any;
        };
        /** Whether this trial is a target trial */
        readonly is_target: {
            readonly type: ParameterType.BOOL;
            readonly default: false;
        };
        /** Duration the stimulus is displayed (ms). If null, waits indefinitely for response */
        readonly stimulus_duration: {
            readonly type: ParameterType.INT;
            readonly default: any;
        };
        /** Inter-stimulus interval (ms) */
        readonly isi_duration: {
            readonly type: ParameterType.INT;
            readonly default: 500;
        };
        /** Duration of feedback display (ms) */
        readonly feedback_duration: {
            readonly type: ParameterType.INT;
            readonly default: 0;
        };
        /** Whether to show feedback "Incorrect! (231ms)" after response */
        readonly show_feedback_text: {
            readonly type: ParameterType.BOOL;
            readonly default: true;
        };
        /** Whether to show feedback border around the grid */
        readonly show_feedback_border: {
            readonly type: ParameterType.BOOL;
            readonly default: true;
        };
        /** Labels for the response buttons. First button is for match, second is for no match */
        readonly buttons: {
            readonly type: ParameterType.STRING;
            readonly default: readonly ["MATCH", "NO MATCH"];
            readonly array: true;
        };
        /** Index of the match button in the buttons array */
        readonly match_index: {
            readonly type: ParameterType.INT;
            readonly default: 0;
        };
        /** Color of the stimulus square */
        readonly stimulus_color: {
            readonly type: ParameterType.STRING;
            readonly default: "#0066cc";
        };
        /** Color of correct feedback border */
        readonly correct_color: {
            readonly type: ParameterType.STRING;
            readonly default: "#00cc00";
        };
        /** Color of incorrect feedback border */
        readonly incorrect_color: {
            readonly type: ParameterType.STRING;
            readonly default: "#cc0000";
        };
        /** Instructions to display above the grid */
        readonly instructions: {
            readonly type: ParameterType.STRING;
            readonly default: "";
        };
    };
    readonly data: {
        /** Row position of the stimulus */
        readonly stimulus_row: {
            readonly type: ParameterType.INT;
        };
        /** Column position of the stimulus */
        readonly stimulus_col: {
            readonly type: ParameterType.INT;
        };
        /** Whether this trial was a target */
        readonly is_target: {
            readonly type: ParameterType.BOOL;
        };
        /** Index of button pressed (match_index for match, other indices for no match), null if no response. */
        readonly response: {
            readonly type: ParameterType.INT;
        };
        /** Response time in milliseconds */
        readonly response_time: {
            readonly type: ParameterType.INT;
        };
        /** Whether the response was correct, based on match_index parameter and is_target. */
        readonly correct: {
            readonly type: ParameterType.BOOL;
        };
    };
    readonly citations: "__CITATIONS__";
};
type Info = typeof info;
/**
 * **plugin-spatial-nback**
 *
 * Single trial spatial grid stimulus with response collection
 *
 * @author A. Hunter Farhat
 * @version 1.0.0
 * @see {@link https://github.com/farhat60/jspsych-contrib/packages/plugin-spatial-nback}
 */
declare class SpatialNbackPlugin implements JsPsychPlugin<Info> {
    private jsPsych;
    static info: {
        readonly name: "spatial-nback";
        readonly version: string;
        readonly parameters: {
            /** Number of rows in the spatial grid */
            readonly rows: {
                readonly type: ParameterType.INT;
                readonly default: 3;
            };
            /** Number of columns in the spatial grid */
            readonly cols: {
                readonly type: ParameterType.INT;
                readonly default: 3;
            };
            /** Size of each cell in pixels, this will affect size of whole grid also. If null, defaults to 12vh (12% of viewport height) */
            readonly cell_size: {
                readonly type: ParameterType.INT;
                readonly default: any;
            };
            /** Row position of the stimulus (0-indexed). If null, no stimulus is shown. */
            readonly stimulus_row: {
                readonly type: ParameterType.INT;
                readonly default: any;
            };
            /** Column position of the stimulus (0-indexed). If null, no stimulus is shown. */
            readonly stimulus_col: {
                readonly type: ParameterType.INT;
                readonly default: any;
            };
            /** Whether this trial is a target trial */
            readonly is_target: {
                readonly type: ParameterType.BOOL;
                readonly default: false;
            };
            /** Duration the stimulus is displayed (ms). If null, waits indefinitely for response */
            readonly stimulus_duration: {
                readonly type: ParameterType.INT;
                readonly default: any;
            };
            /** Inter-stimulus interval (ms) */
            readonly isi_duration: {
                readonly type: ParameterType.INT;
                readonly default: 500;
            };
            /** Duration of feedback display (ms) */
            readonly feedback_duration: {
                readonly type: ParameterType.INT;
                readonly default: 0;
            };
            /** Whether to show feedback "Incorrect! (231ms)" after response */
            readonly show_feedback_text: {
                readonly type: ParameterType.BOOL;
                readonly default: true;
            };
            /** Whether to show feedback border around the grid */
            readonly show_feedback_border: {
                readonly type: ParameterType.BOOL;
                readonly default: true;
            };
            /** Labels for the response buttons. First button is for match, second is for no match */
            readonly buttons: {
                readonly type: ParameterType.STRING;
                readonly default: readonly ["MATCH", "NO MATCH"];
                readonly array: true;
            };
            /** Index of the match button in the buttons array */
            readonly match_index: {
                readonly type: ParameterType.INT;
                readonly default: 0;
            };
            /** Color of the stimulus square */
            readonly stimulus_color: {
                readonly type: ParameterType.STRING;
                readonly default: "#0066cc";
            };
            /** Color of correct feedback border */
            readonly correct_color: {
                readonly type: ParameterType.STRING;
                readonly default: "#00cc00";
            };
            /** Color of incorrect feedback border */
            readonly incorrect_color: {
                readonly type: ParameterType.STRING;
                readonly default: "#cc0000";
            };
            /** Instructions to display above the grid */
            readonly instructions: {
                readonly type: ParameterType.STRING;
                readonly default: "";
            };
        };
        readonly data: {
            /** Row position of the stimulus */
            readonly stimulus_row: {
                readonly type: ParameterType.INT;
            };
            /** Column position of the stimulus */
            readonly stimulus_col: {
                readonly type: ParameterType.INT;
            };
            /** Whether this trial was a target */
            readonly is_target: {
                readonly type: ParameterType.BOOL;
            };
            /** Index of button pressed (match_index for match, other indices for no match), null if no response. */
            readonly response: {
                readonly type: ParameterType.INT;
            };
            /** Response time in milliseconds */
            readonly response_time: {
                readonly type: ParameterType.INT;
            };
            /** Whether the response was correct, based on match_index parameter and is_target. */
            readonly correct: {
                readonly type: ParameterType.BOOL;
            };
        };
        readonly citations: "__CITATIONS__";
    };
    constructor(jsPsych: JsPsych);
    trial(display_element: HTMLElement, trial: TrialType<Info>): void;
}

export { SpatialNbackPlugin as default };
